/**
    @file ft51_iocell_registers.h

    @brief IO Cell registers library

    Defines registers and bit-masks associated with IO Cell control.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_IOCELL_REGISTERS_H__
#define __FT51_IOCELL_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 256 (0x100) AIO_CONTROL
#define AIO_CONTROL                           0x100

// Register 256 Bit Definitions
#define BIT_AIO_SOFT_RESET                    0                                 // Write a 1 to reset IO_CELL_CNTRL
#define MASK_AIO_SOFT_RESET                   (0x1 << BIT_AIO_SOFT_RESET)
#define BIT_AIO_DEV_EN                        1                                 // Write a 1 to enable IO_CELL_CNTRL
#define MASK_AIO_DEV_EN                       (0x1 << BIT_AIO_DEV_EN)

//------------------------------------------------------------------------------
// Register 257 (0x101) AIO_GLOBAL_CTRL
#define AIO_GLOBAL_CTRL                       0x101

// Register 257 Bit Definitions
#define BIT_GLOBAL_SAMPLE                     0                                 // Write a 1 to sample all IO_CELL pads simultaneously
#define MASK_GLOBAL_SAMPLE                    (0x1 << BIT_GLOBAL_SAMPLE)
#define BIT_GLOBAL_SAMPLE_INT                 2                                 // Interrupt to indicate Global sample has completed
#define MASK_GLOBAL_SAMPLE_INT                (0x1 << BIT_GLOBAL_SAMPLE_INT)
#define BIT_GLOBAL_SAMPLE_IEN                 3                                 // Enable bit for Global Sample Interrupt
#define MASK_GLOBAL_SAMPLE_IEN                (0x1 << BIT_GLOBAL_SAMPLE_IEN)

//------------------------------------------------------------------------------
// Register 258 (0x102) AIO_MODE_0
#define AIO_MODE_0                            0x102

// Register 258 Bit Definitions
#define BIT_AIO_0_MODE_0                      0                                 // Lower bit of MODE bits
#define MASK_AIO_0_MODE_0                     (0x1 << BIT_AIO_0_MODE_0)
#define BIT_AIO_0_MODE_1                      1                                 // Upper bit of MODE bits
#define MASK_AIO_0_MODE_1                     (0x1 << BIT_AIO_0_MODE_1)
#define BIT_AIO_1_MODE_0                      2                                 // Lower bit of MODE bits
#define MASK_AIO_1_MODE_0                     (0x1 << BIT_AIO_1_MODE_0)
#define BIT_AIO_1_MODE_1                      3                                 // Upper bit of MODE bits
#define MASK_AIO_1_MODE_1                     (0x1 << BIT_AIO_1_MODE_1)
#define BIT_AIO_2_MODE_0                      4                                 // Lower bit of MODE bits
#define MASK_AIO_2_MODE_0                     (0x1 << BIT_AIO_2_MODE_0)
#define BIT_AIO_2_MODE_1                      5                                 // Upper bit of MODE bits
#define MASK_AIO_2_MODE_1                     (0x1 << BIT_AIO_2_MODE_1)
#define BIT_AIO_3_MODE_0                      6                                 // Lower bit of MODE bits
#define MASK_AIO_3_MODE_0                     (0x1 << BIT_AIO_3_MODE_0)
#define BIT_AIO_3_MODE_1                      7                                 // Upper bit of MODE bits
#define MASK_AIO_3_MODE_1                     (0x1 << BIT_AIO_3_MODE_1)

//------------------------------------------------------------------------------
// Register 259 (0x103) AIO_MODE_1
#define AIO_MODE_1                            0x103

// Register 259 Bit Definitions
#define BIT_AIO_4_MODE_0                      0                                 // Lower bit of MODE bits
#define MASK_AIO_4_MODE_0                     (0x1 << BIT_AIO_4_MODE_0)
#define BIT_AIO_4_MODE_1                      1                                 // Upper bit of MODE bits
#define MASK_AIO_4_MODE_1                     (0x1 << BIT_AIO_4_MODE_1)
#define BIT_AIO_5_MODE_0                      2                                 // Lower bit of MODE bits
#define MASK_AIO_5_MODE_0                     (0x1 << BIT_AIO_5_MODE_0)
#define BIT_AIO_5_MODE_1                      3                                 // Upper bit of MODE bits
#define MASK_AIO_5_MODE_1                     (0x1 << BIT_AIO_5_MODE_1)
#define BIT_AIO_6_MODE_0                      4                                 // Lower bit of MODE bits
#define MASK_AIO_6_MODE_0                     (0x1 << BIT_AIO_6_MODE_0)
#define BIT_AIO_6_MODE_1                      5                                 // Upper bit of MODE bits
#define MASK_AIO_6_MODE_1                     (0x1 << BIT_AIO_6_MODE_1)
#define BIT_AIO_7_MODE_0                      6                                 // Lower bit of MODE bits
#define MASK_AIO_7_MODE_0                     (0x1 << BIT_AIO_7_MODE_0)
#define BIT_AIO_7_MODE_1                      7                                 // Upper bit of MODE bits
#define MASK_AIO_7_MODE_1                     (0x1 << BIT_AIO_7_MODE_1)

//------------------------------------------------------------------------------
// Register 260 (0x104) AIO_MODE_2
#define AIO_MODE_2                            0x104

// Register 260 Bit Definitions
#define BIT_AIO_8_MODE_0                      0                                 // Lower bit of MODE bits
#define MASK_AIO_8_MODE_0                     (0x1 << BIT_AIO_8_MODE_0)
#define BIT_AIO_8_MODE_1                      1                                 // Upper bit of MODE bits
#define MASK_AIO_8_MODE_1                     (0x1 << BIT_AIO_8_MODE_1)
#define BIT_AIO_9_MODE_0                      2                                 // Lower bit of MODE bits
#define MASK_AIO_9_MODE_0                     (0x1 << BIT_AIO_9_MODE_0)
#define BIT_AIO_9_MODE_1                      3                                 // Upper bit of MODE bits
#define MASK_AIO_9_MODE_1                     (0x1 << BIT_AIO_9_MODE_1)
#define BIT_AIO_10_MODE_0                     4                                 // Lower bit of MODE bits
#define MASK_AIO_10_MODE_0                    (0x1 << BIT_AIO_10_MODE_0)
#define BIT_AIO_10_MODE_1                     5                                 // Upper bit of MODE bits
#define MASK_AIO_10_MODE_1                    (0x1 << BIT_AIO_10_MODE_1)
#define BIT_AIO_11_MODE_0                     6                                 // Lower bit of MODE bits
#define MASK_AIO_11_MODE_0                    (0x1 << BIT_AIO_11_MODE_0)
#define BIT_AIO_11_MODE_1                     7                                 // Upper bit of MODE bits
#define MASK_AIO_11_MODE_1                    (0x1 << BIT_AIO_11_MODE_1)

//------------------------------------------------------------------------------
// Register 261 (0x105) AIO_MODE_3
#define AIO_MODE_3                            0x105

// Register 261 Bit Definitions
#define BIT_AIO_12_MODE_0                     0                                 // Lower bit of MODE bits
#define MASK_AIO_12_MODE_0                    (0x1 << BIT_AIO_12_MODE_0)
#define BIT_AIO_12_MODE_1                     1                                 // Upper bit of MODE bits
#define MASK_AIO_12_MODE_1                    (0x1 << BIT_AIO_12_MODE_1)
#define BIT_AIO_13_MODE_0                     2                                 // Lower bit of MODE bits
#define MASK_AIO_13_MODE_0                    (0x1 << BIT_AIO_13_MODE_0)
#define BIT_AIO_13_MODE_1                     3                                 // Upper bit of MODE bits
#define MASK_AIO_13_MODE_1                    (0x1 << BIT_AIO_13_MODE_1)
#define BIT_AIO_14_MODE_0                     4                                 // Lower bit of MODE bits
#define MASK_AIO_14_MODE_0                    (0x1 << BIT_AIO_14_MODE_0)
#define BIT_AIO_14_MODE_1                     5                                 // Upper bit of MODE bits
#define MASK_AIO_14_MODE_1                    (0x1 << BIT_AIO_14_MODE_1)
#define BIT_AIO_15_MODE_0                     6                                 // Lower bit of MODE bits
#define MASK_AIO_15_MODE_0                    (0x1 << BIT_AIO_15_MODE_0)
#define BIT_AIO_15_MODE_1                     7                                 // Upper bit of MODE bits
#define MASK_AIO_15_MODE_1                    (0x1 << BIT_AIO_15_MODE_1)

//------------------------------------------------------------------------------
// Register 262 (0x106) IO_CELL_ANA_MODE_4_1
#define IO_CELL_ANA_MODE_4_1                  0x106

// Register 262 Bit Definitions
#define BIT_CELL_16_MODE_0                    0                                 // Lower bit of MODE bits
#define MASK_CELL_16_MODE_0                   (0x1 << BIT_CELL_16_MODE_0)
#define BIT_CELL_16_MODE_1                    1                                 // Upper bit of MODE bits
#define MASK_CELL_16_MODE_1                   (0x1 << BIT_CELL_16_MODE_1)
#define BIT_CELL_17_MODE_0                    2                                 // Lower bit of MODE bits
#define MASK_CELL_17_MODE_0                   (0x1 << BIT_CELL_17_MODE_0)
#define BIT_CELL_17_MODE_1                    3                                 // Upper bit of MODE bits
#define MASK_CELL_17_MODE_1                   (0x1 << BIT_CELL_17_MODE_1)
#define BIT_CELL_18_MODE_0                    4                                 // Lower bit of MODE bits
#define MASK_CELL_18_MODE_0                   (0x1 << BIT_CELL_18_MODE_0)
#define BIT_CELL_18_MODE_1                    5                                 // Upper bit of MODE bits
#define MASK_CELL_18_MODE_1                   (0x1 << BIT_CELL_18_MODE_1)
#define BIT_CELL_19_MODE_0                    6                                 // Lower bit of MODE bits
#define MASK_CELL_19_MODE_0                   (0x1 << BIT_CELL_19_MODE_0)
#define BIT_CELL_19_MODE_1                    7                                 // Upper bit of MODE bits
#define MASK_CELL_19_MODE_1                   (0x1 << BIT_CELL_19_MODE_1)

//------------------------------------------------------------------------------
// Register 263 (0x107) IO_CELL_ANA_MODE_5_1
#define IO_CELL_ANA_MODE_5_1                  0x107

// Register 263 Bit Definitions
#define BIT_CELL_20_MODE_0                    0                                 // Lower bit of MODE bits
#define MASK_CELL_20_MODE_0                   (0x1 << BIT_CELL_20_MODE_0)
#define BIT_CELL_20_MODE_1                    1                                 // Upper bit of MODE bits
#define MASK_CELL_20_MODE_1                   (0x1 << BIT_CELL_20_MODE_1)
#define BIT_CELL_21_MODE_0                    2                                 // Lower bit of MODE bits
#define MASK_CELL_21_MODE_0                   (0x1 << BIT_CELL_21_MODE_0)
#define BIT_CELL_21_MODE_1                    3                                 // Upper bit of MODE bits
#define MASK_CELL_21_MODE_1                   (0x1 << BIT_CELL_21_MODE_1)
#define BIT_CELL_22_MODE_0                    4                                 // Lower bit of MODE bits
#define MASK_CELL_22_MODE_0                   (0x1 << BIT_CELL_22_MODE_0)
#define BIT_CELL_22_MODE_1                    5                                 // Upper bit of MODE bits
#define MASK_CELL_22_MODE_1                   (0x1 << BIT_CELL_22_MODE_1)
#define BIT_CELL_23_MODE_0                    6                                 // Lower bit of MODE bits
#define MASK_CELL_23_MODE_0                   (0x1 << BIT_CELL_23_MODE_0)
#define BIT_CELL_23_MODE_1                    7                                 // Upper bit of MODE bits
#define MASK_CELL_23_MODE_1                   (0x1 << BIT_CELL_23_MODE_1)

//------------------------------------------------------------------------------
// Register 264 (0x108) AIO_SAMPLE_0
#define AIO_SAMPLE_0                          0x108

// Register 264 Bit Definitions
#define BIT_AIO_0_SAMPLE                      0                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_0_SAMPLE                     (0x1 << BIT_AIO_0_SAMPLE    )
#define BIT_AIO_1_SAMPLE                      1                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_1_SAMPLE                     (0x1 << BIT_AIO_1_SAMPLE    )
#define BIT_AIO_2_SAMPLE                      2                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_2_SAMPLE                     (0x1 << BIT_AIO_2_SAMPLE    )
#define BIT_AIO_3_SAMPLE                      3                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_3_SAMPLE                     (0x1 << BIT_AIO_3_SAMPLE    )
#define BIT_AIO_4_SAMPLE                      4                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_4_SAMPLE                     (0x1 << BIT_AIO_4_SAMPLE    )
#define BIT_AIO_5_SAMPLE                      5                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_5_SAMPLE                     (0x1 << BIT_AIO_5_SAMPLE    )
#define BIT_AIO_6_SAMPLE                      6                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_6_SAMPLE                     (0x1 << BIT_AIO_6_SAMPLE    )
#define BIT_AIO_7_SAMPLE                      7                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_7_SAMPLE                     (0x1 << BIT_AIO_7_SAMPLE    )

//------------------------------------------------------------------------------
// Register 265 (0x109) AIO_SAMPLE_1
#define AIO_SAMPLE_1                          0x109

// Register 265 Bit Definitions
#define BIT_AIO_8_SAMPLE                      0                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_8_SAMPLE                     (0x1 << BIT_AIO_8_SAMPLE    )
#define BIT_AIO_9_SAMPLE                      1                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_9_SAMPLE                     (0x1 << BIT_AIO_9_SAMPLE    )
#define BIT_AIO_10_SAMPLE                     2                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_10_SAMPLE                    (0x1 << BIT_AIO_10_SAMPLE    )
#define BIT_AIO_11_SAMPLE                     3                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_11_SAMPLE                    (0x1 << BIT_AIO_11_SAMPLE    )
#define BIT_AIO_12_SAMPLE                     4                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_12_SAMPLE                    (0x1 << BIT_AIO_12_SAMPLE    )
#define BIT_AIO_13_SAMPLE                     5                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_13_SAMPLE                    (0x1 << BIT_AIO_13_SAMPLE    )
#define BIT_AIO_14_SAMPLE                     6                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_14_SAMPLE                    (0x1 << BIT_AIO_14_SAMPLE    )
#define BIT_AIO_15_SAMPLE                     7                                 // 1=Sample pulse, 0=no effect
#define MASK_AIO_15_SAMPLE                    (0x1 << BIT_AIO_15_SAMPLE    )

//------------------------------------------------------------------------------
// Register 266 (0x10A) IO_CELL_SAMPLE_16_23_1
#define IO_CELL_SAMPLE_16_23_1                0x10A

// Register 266 Bit Definitions
#define BIT_IO_CELL_16_SAMPLE                 0                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_16_SAMPLE                (0x1 << BIT_IO_CELL_16_SAMPLE)
#define BIT_IO_CELL_17_SAMPLE                 1                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_17_SAMPLE                (0x1 << BIT_IO_CELL_17_SAMPLE)
#define BIT_IO_CELL_18_SAMPLE                 2                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_18_SAMPLE                (0x1 << BIT_IO_CELL_18_SAMPLE)
#define BIT_IO_CELL_19_SAMPLE                 3                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_19_SAMPLE                (0x1 << BIT_IO_CELL_19_SAMPLE)
#define BIT_IO_CELL_20_SAMPLE                 4                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_20_SAMPLE                (0x1 << BIT_IO_CELL_20_SAMPLE)
#define BIT_IO_CELL_21_SAMPLE                 5                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_21_SAMPLE                (0x1 << BIT_IO_CELL_21_SAMPLE)
#define BIT_IO_CELL_22_SAMPLE                 6                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_22_SAMPLE                (0x1 << BIT_IO_CELL_22_SAMPLE)
#define BIT_IO_CELL_23_SAMPLE                 7                                 // 1=Sample pulse, 0=no effect
#define MASK_IO_CELL_23_SAMPLE                (0x1 << BIT_IO_CELL_23_SAMPLE)

//------------------------------------------------------------------------------
// Register 267 (0x10B) AIO_GLOBAL_PORT_SELECT_0_7
#define AIO_GLOBAL_PORT_SELECT_0_7            0x10B

// Register 267 Bit Definitions
#define BIT_AIO_PORT_0_ACTIVE                 0                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_0_ACTIVE                (0x1 << BIT_AIO_PORT_0_ACTIVE)
#define BIT_AIO_PORT_1_ACTIVE                 1                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_1_ACTIVE                (0x1 << BIT_AIO_PORT_1_ACTIVE)
#define BIT_AIO_PORT_2_ACTIVE                 2                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_2_ACTIVE                (0x1 << BIT_AIO_PORT_2_ACTIVE)
#define BIT_AIO_PORT_3_ACTIVE                 3                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_3_ACTIVE                (0x1 << BIT_AIO_PORT_3_ACTIVE)
#define BIT_AIO_PORT_4_ACTIVE                 4                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_4_ACTIVE                (0x1 << BIT_AIO_PORT_4_ACTIVE)
#define BIT_AIO_PORT_5_ACTIVE                 5                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_5_ACTIVE                (0x1 << BIT_AIO_PORT_5_ACTIVE)
#define BIT_AIO_PORT_6_ACTIVE                 6                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_6_ACTIVE                (0x1 << BIT_AIO_PORT_6_ACTIVE)
#define BIT_AIO_PORT_7_ACTIVE                 7                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_7_ACTIVE                (0x1 << BIT_AIO_PORT_7_ACTIVE)

//------------------------------------------------------------------------------
// Register 268 (0x10C) IO_CELL_GLOB_CELLS_8_15_1
#define AIO_GLOBAL_PORT_SELECT_8_15           0x10C

// Register 268 Bit Definitions
#define BIT_AIO_PORT_8_ACTIVE                 0                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_8_ACTIVE                (0x1 << BIT_AIO_PORT_8_ACTIVE)
#define BIT_AIO_PORT_9_ACTIVE                 1                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_9_ACTIVE                (0x1 << BIT_AIO_PORT_9_ACTIVE)
#define BIT_AIO_PORT_10_ACTIVE                2                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_10_ACTIVE               (0x1 << BIT_AIO_PORT_10_ACTIVE)
#define BIT_AIO_PORT_11_ACTIVE                3                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_11_ACTIVE               (0x1 << BIT_AIO_PORT_11_ACTIVE)
#define BIT_AIO_PORT_12_ACTIVE                4                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_12_ACTIVE               (0x1 << BIT_AIO_PORT_12_ACTIVE)
#define BIT_AIO_PORT_13_ACTIVE                5                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_13_ACTIVE               (0x1 << BIT_AIO_PORT_13_ACTIVE)
#define BIT_AIO_PORT_14_ACTIVE                6                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_14_ACTIVE               (0x1 << BIT_AIO_PORT_14_ACTIVE)
#define BIT_AIO_PORT_15_ACTIVE                7                                 // 1=Active, 0=Not Active
#define MASK_AIO_PORT_15_ACTIVE               (0x1 << BIT_AIO_PORT_15_ACTIVE)

//------------------------------------------------------------------------------
// Register 318 (0x13E) AIO_0_ADC_DATA_L_1
#define AIO_0_ADC_DATA_L_1                0x13E

// Register 318 Bit Definitions
#define BIT_AIO_0_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_0               (0x1 << BIT_AIO_0_ADC_DATA_L_0 )
#define BIT_AIO_0_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_1               (0x1 << BIT_AIO_0_ADC_DATA_L_1 )
#define BIT_AIO_0_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_2               (0x1 << BIT_AIO_0_ADC_DATA_L_2 )
#define BIT_AIO_0_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_3               (0x1 << BIT_AIO_0_ADC_DATA_L_3 )
#define BIT_AIO_0_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_4               (0x1 << BIT_AIO_0_ADC_DATA_L_4 )
#define BIT_AIO_0_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_5               (0x1 << BIT_AIO_0_ADC_DATA_L_5 )
#define BIT_AIO_0_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_6               (0x1 << BIT_AIO_0_ADC_DATA_L_6 )
#define BIT_AIO_0_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 0, Lower 8 bits
#define MASK_AIO_0_ADC_DATA_L_7               (0x1 << BIT_AIO_0_ADC_DATA_L_7 )
#define MASK_CELL_0_ADC_DATA_L                (0xFF << BIT_AIO_0_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 319 (0x13F) AIO_0_ADC_DATA_U_1
#define AIO_0_ADC_DATA_U_1                0x13F

// Register 319 Bit Definitions
#define BIT_AIO_0_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 0, Upper 2 bits
#define MASK_AIO_0_ADC_DATA_U_0               (0x1 << BIT_AIO_0_ADC_DATA_U_0 )
#define BIT_AIO_0_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 0, Upper 2 bits
#define MASK_AIO_0_ADC_DATA_U_1               (0x1 << BIT_AIO_0_ADC_DATA_U_1 )
#define MASK_CELL_0_ADC_DATA_U                (0x3 << BIT_AIO_0_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 320 (0x140) AIO_1_ADC_DATA_L_1
#define AIO_1_ADC_DATA_L_1                0x140

// Register 320 Bit Definitions
#define BIT_AIO_1_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_0               (0x1 << BIT_AIO_1_ADC_DATA_L_0 )
#define BIT_AIO_1_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_1               (0x1 << BIT_AIO_1_ADC_DATA_L_1 )
#define BIT_AIO_1_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_2               (0x1 << BIT_AIO_1_ADC_DATA_L_2 )
#define BIT_AIO_1_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_3               (0x1 << BIT_AIO_1_ADC_DATA_L_3 )
#define BIT_AIO_1_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_4               (0x1 << BIT_AIO_1_ADC_DATA_L_4 )
#define BIT_AIO_1_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_5               (0x1 << BIT_AIO_1_ADC_DATA_L_5 )
#define BIT_AIO_1_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_6               (0x1 << BIT_AIO_1_ADC_DATA_L_6 )
#define BIT_AIO_1_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 1, Lower 8 bits
#define MASK_AIO_1_ADC_DATA_L_7               (0x1 << BIT_AIO_1_ADC_DATA_L_7 )
#define MASK_CELL_1_ADC_DATA_L                (0xFF << BIT_AIO_1_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 321 (0x141) AIO_1_ADC_DATA_U_1
#define AIO_1_ADC_DATA_U_1                0x141

// Register 321 Bit Definitions
#define BIT_AIO_1_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 1, Upper 2 bits
#define MASK_AIO_1_ADC_DATA_U_0               (0x1 << BIT_AIO_1_ADC_DATA_U_0 )
#define BIT_AIO_1_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 1, Upper 2 bits
#define MASK_AIO_1_ADC_DATA_U_1               (0x1 << BIT_AIO_1_ADC_DATA_U_1 )
#define MASK_CELL_1_ADC_DATA_U                (0x3 << BIT_AIO_1_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 322 (0x142) AIO_2_ADC_DATA_L_1
#define AIO_2_ADC_DATA_L_1                0x142

// Register 322 Bit Definitions
#define BIT_AIO_2_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_0               (0x1 << BIT_AIO_2_ADC_DATA_L_0 )
#define BIT_AIO_2_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_1               (0x1 << BIT_AIO_2_ADC_DATA_L_1 )
#define BIT_AIO_2_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_2               (0x1 << BIT_AIO_2_ADC_DATA_L_2 )
#define BIT_AIO_2_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_3               (0x1 << BIT_AIO_2_ADC_DATA_L_3 )
#define BIT_AIO_2_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_4               (0x1 << BIT_AIO_2_ADC_DATA_L_4 )
#define BIT_AIO_2_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_5               (0x1 << BIT_AIO_2_ADC_DATA_L_5 )
#define BIT_AIO_2_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_6               (0x1 << BIT_AIO_2_ADC_DATA_L_6 )
#define BIT_AIO_2_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 2, Lower 8 bits
#define MASK_AIO_2_ADC_DATA_L_7               (0x1 << BIT_AIO_2_ADC_DATA_L_7 )
#define MASK_CELL_2_ADC_DATA_L                (0xFF << BIT_AIO_2_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 323 (0x143) AIO_2_ADC_DATA_U_1
#define AIO_2_ADC_DATA_U_1                0x143

// Register 323 Bit Definitions
#define BIT_AIO_2_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 2, Upper 2 bits
#define MASK_AIO_2_ADC_DATA_U_0               (0x1 << BIT_AIO_2_ADC_DATA_U_0 )
#define BIT_AIO_2_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 2, Upper 2 bits
#define MASK_AIO_2_ADC_DATA_U_1               (0x1 << BIT_AIO_2_ADC_DATA_U_1 )
#define MASK_CELL_2_ADC_DATA_U                (0x3 << BIT_AIO_2_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 324 (0x144) AIO_3_ADC_DATA_L_1
#define AIO_3_ADC_DATA_L_1                0x144

// Register 324 Bit Definitions
#define BIT_AIO_3_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_0               (0x1 << BIT_AIO_3_ADC_DATA_L_0 )
#define BIT_AIO_3_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_1               (0x1 << BIT_AIO_3_ADC_DATA_L_1 )
#define BIT_AIO_3_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_2               (0x1 << BIT_AIO_3_ADC_DATA_L_2 )
#define BIT_AIO_3_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_3               (0x1 << BIT_AIO_3_ADC_DATA_L_3 )
#define BIT_AIO_3_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_4               (0x1 << BIT_AIO_3_ADC_DATA_L_4 )
#define BIT_AIO_3_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_5               (0x1 << BIT_AIO_3_ADC_DATA_L_5 )
#define BIT_AIO_3_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_6               (0x1 << BIT_AIO_3_ADC_DATA_L_6 )
#define BIT_AIO_3_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 3, Lower 8 bits
#define MASK_AIO_3_ADC_DATA_L_7               (0x1 << BIT_AIO_3_ADC_DATA_L_7 )
#define MASK_CELL_3_ADC_DATA_L                (0xFF << BIT_AIO_3_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 325 (0x145) AIO_3_ADC_DATA_U_1
#define AIO_3_ADC_DATA_U_1                0x145

// Register 325 Bit Definitions
#define BIT_AIO_3_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 3, Upper 2 bits
#define MASK_AIO_3_ADC_DATA_U_0               (0x1 << BIT_AIO_3_ADC_DATA_U_0 )
#define BIT_AIO_3_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 3, Upper 2 bits
#define MASK_AIO_3_ADC_DATA_U_1               (0x1 << BIT_AIO_3_ADC_DATA_U_1 )
#define MASK_CELL_3_ADC_DATA_U                (0x3 << BIT_AIO_3_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 326 (0x146) AIO_4_ADC_DATA_L_1
#define AIO_4_ADC_DATA_L_1                0x146

// Register 326 Bit Definitions
#define BIT_AIO_4_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_0               (0x1 << BIT_AIO_4_ADC_DATA_L_0 )
#define BIT_AIO_4_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_1               (0x1 << BIT_AIO_4_ADC_DATA_L_1 )
#define BIT_AIO_4_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_2               (0x1 << BIT_AIO_4_ADC_DATA_L_2 )
#define BIT_AIO_4_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_3               (0x1 << BIT_AIO_4_ADC_DATA_L_3 )
#define BIT_AIO_4_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_4               (0x1 << BIT_AIO_4_ADC_DATA_L_4 )
#define BIT_AIO_4_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_5               (0x1 << BIT_AIO_4_ADC_DATA_L_5 )
#define BIT_AIO_4_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_6               (0x1 << BIT_AIO_4_ADC_DATA_L_6 )
#define BIT_AIO_4_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 4, Lower 8 bits
#define MASK_AIO_4_ADC_DATA_L_7               (0x1 << BIT_AIO_4_ADC_DATA_L_7 )
#define MASK_CELL_4_ADC_DATA_L                (0xFF << BIT_AIO_4_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 327 (0x147) AIO_4_ADC_DATA_U_1
#define AIO_4_ADC_DATA_U_1                0x147

// Register 327 Bit Definitions
#define BIT_AIO_4_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 4, Upper 2 bits
#define MASK_AIO_4_ADC_DATA_U_0               (0x1 << BIT_AIO_4_ADC_DATA_U_0 )
#define BIT_AIO_4_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 4, Upper 2 bits
#define MASK_AIO_4_ADC_DATA_U_1               (0x1 << BIT_AIO_4_ADC_DATA_U_1 )
#define MASK_CELL_4_ADC_DATA_U                (0x3 << BIT_AIO_4_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 328 (0x148) AIO_5_ADC_DATA_L_1
#define AIO_5_ADC_DATA_L_1                0x148

// Register 328 Bit Definitions
#define BIT_AIO_5_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_0               (0x1 << BIT_AIO_5_ADC_DATA_L_0 )
#define BIT_AIO_5_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_1               (0x1 << BIT_AIO_5_ADC_DATA_L_1 )
#define BIT_AIO_5_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_2               (0x1 << BIT_AIO_5_ADC_DATA_L_2 )
#define BIT_AIO_5_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_3               (0x1 << BIT_AIO_5_ADC_DATA_L_3 )
#define BIT_AIO_5_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_4               (0x1 << BIT_AIO_5_ADC_DATA_L_4 )
#define BIT_AIO_5_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_5               (0x1 << BIT_AIO_5_ADC_DATA_L_5 )
#define BIT_AIO_5_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_6               (0x1 << BIT_AIO_5_ADC_DATA_L_6 )
#define BIT_AIO_5_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 5, Lower 8 bits
#define MASK_AIO_5_ADC_DATA_L_7               (0x1 << BIT_AIO_5_ADC_DATA_L_7 )
#define MASK_CELL_5_ADC_DATA_L                (0xFF << BIT_AIO_5_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 329 (0x149) AIO_5_ADC_DATA_U_1
#define AIO_5_ADC_DATA_U_1                0x149

// Register 329 Bit Definitions
#define BIT_AIO_5_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 5, Upper 2 bits
#define MASK_AIO_5_ADC_DATA_U_0               (0x1 << BIT_AIO_5_ADC_DATA_U_0 )
#define BIT_AIO_5_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 5, Upper 2 bits
#define MASK_AIO_5_ADC_DATA_U_1               (0x1 << BIT_AIO_5_ADC_DATA_U_1 )
#define MASK_CELL_5_ADC_DATA_U                (0x3 << BIT_AIO_5_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 330 (0x14A) AIO_6_ADC_DATA_L_1
#define AIO_6_ADC_DATA_L_1                0x14A

// Register 330 Bit Definitions
#define BIT_AIO_6_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_0               (0x1 << BIT_AIO_6_ADC_DATA_L_0 )
#define BIT_AIO_6_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_1               (0x1 << BIT_AIO_6_ADC_DATA_L_1 )
#define BIT_AIO_6_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_2               (0x1 << BIT_AIO_6_ADC_DATA_L_2 )
#define BIT_AIO_6_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_3               (0x1 << BIT_AIO_6_ADC_DATA_L_3 )
#define BIT_AIO_6_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_4               (0x1 << BIT_AIO_6_ADC_DATA_L_4 )
#define BIT_AIO_6_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_5               (0x1 << BIT_AIO_6_ADC_DATA_L_5 )
#define BIT_AIO_6_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_6               (0x1 << BIT_AIO_6_ADC_DATA_L_6 )
#define BIT_AIO_6_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 6, Lower 8 bits
#define MASK_AIO_6_ADC_DATA_L_7               (0x1 << BIT_AIO_6_ADC_DATA_L_7 )
#define MASK_CELL_6_ADC_DATA_L                (0xFF << BIT_AIO_6_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 331 (0x14B) AIO_6_ADC_DATA_U_1
#define AIO_6_ADC_DATA_U_1                0x14B

// Register 331 Bit Definitions
#define BIT_AIO_6_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 6, Upper 2 bits
#define MASK_AIO_6_ADC_DATA_U_0               (0x1 << BIT_AIO_6_ADC_DATA_U_0 )
#define BIT_AIO_6_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 6, Upper 2 bits
#define MASK_AIO_6_ADC_DATA_U_1               (0x1 << BIT_AIO_6_ADC_DATA_U_1 )
#define MASK_CELL_6_ADC_DATA_U                (0x3 << BIT_AIO_6_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 332 (0x14C) AIO_7_ADC_DATA_L_1
#define AIO_7_ADC_DATA_L_1                0x14C

// Register 332 Bit Definitions
#define BIT_AIO_7_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_0               (0x1 << BIT_AIO_7_ADC_DATA_L_0 )
#define BIT_AIO_7_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_1               (0x1 << BIT_AIO_7_ADC_DATA_L_1 )
#define BIT_AIO_7_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_2               (0x1 << BIT_AIO_7_ADC_DATA_L_2 )
#define BIT_AIO_7_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_3               (0x1 << BIT_AIO_7_ADC_DATA_L_3 )
#define BIT_AIO_7_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_4               (0x1 << BIT_AIO_7_ADC_DATA_L_4 )
#define BIT_AIO_7_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_5               (0x1 << BIT_AIO_7_ADC_DATA_L_5 )
#define BIT_AIO_7_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_6               (0x1 << BIT_AIO_7_ADC_DATA_L_6 )
#define BIT_AIO_7_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 7, Lower 8 bits
#define MASK_AIO_7_ADC_DATA_L_7               (0x1 << BIT_AIO_7_ADC_DATA_L_7 )
#define MASK_CELL_7_ADC_DATA_L                (0xFF << BIT_AIO_7_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 333 (0x14D) AIO_7_ADC_DATA_U_1
#define AIO_7_ADC_DATA_U_1                0x14D

// Register 333 Bit Definitions
#define BIT_AIO_7_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 7, Upper 2 bits
#define MASK_AIO_7_ADC_DATA_U_0               (0x1 << BIT_AIO_7_ADC_DATA_U_0 )
#define BIT_AIO_7_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 7, Upper 2 bits
#define MASK_AIO_7_ADC_DATA_U_1               (0x1 << BIT_AIO_7_ADC_DATA_U_1 )
#define MASK_CELL_7_ADC_DATA_U                (0x3 << BIT_AIO_7_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 334 (0x14E) AIO_8_ADC_DATA_L_1
#define AIO_8_ADC_DATA_L_1                0x14E

// Register 334 Bit Definitions
#define BIT_AIO_8_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_0               (0x1 << BIT_AIO_8_ADC_DATA_L_0 )
#define BIT_AIO_8_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_1               (0x1 << BIT_AIO_8_ADC_DATA_L_1 )
#define BIT_AIO_8_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_2               (0x1 << BIT_AIO_8_ADC_DATA_L_2 )
#define BIT_AIO_8_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_3               (0x1 << BIT_AIO_8_ADC_DATA_L_3 )
#define BIT_AIO_8_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_4               (0x1 << BIT_AIO_8_ADC_DATA_L_4 )
#define BIT_AIO_8_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_5               (0x1 << BIT_AIO_8_ADC_DATA_L_5 )
#define BIT_AIO_8_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_6               (0x1 << BIT_AIO_8_ADC_DATA_L_6 )
#define BIT_AIO_8_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 8, Lower 8 bits
#define MASK_AIO_8_ADC_DATA_L_7               (0x1 << BIT_AIO_8_ADC_DATA_L_7 )
#define MASK_CELL_8_ADC_DATA_L                (0xFF << BIT_AIO_8_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 335 (0x14F) AIO_8_ADC_DATA_U_1
#define AIO_8_ADC_DATA_U_1                0x14F

// Register 335 Bit Definitions
#define BIT_AIO_8_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 8, Upper 2 bits
#define MASK_AIO_8_ADC_DATA_U_0               (0x1 << BIT_AIO_8_ADC_DATA_U_0 )
#define BIT_AIO_8_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 8, Upper 2 bits
#define MASK_AIO_8_ADC_DATA_U_1               (0x1 << BIT_AIO_8_ADC_DATA_U_1 )
#define MASK_CELL_8_ADC_DATA_U                (0x3 << BIT_AIO_8_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 336 (0x150) AIO_9_ADC_DATA_L_1
#define AIO_9_ADC_DATA_L_1                0x150

// Register 336 Bit Definitions
#define BIT_AIO_9_ADC_DATA_L_0                0                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_0               (0x1 << BIT_AIO_9_ADC_DATA_L_0 )
#define BIT_AIO_9_ADC_DATA_L_1                1                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_1               (0x1 << BIT_AIO_9_ADC_DATA_L_1 )
#define BIT_AIO_9_ADC_DATA_L_2                2                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_2               (0x1 << BIT_AIO_9_ADC_DATA_L_2 )
#define BIT_AIO_9_ADC_DATA_L_3                3                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_3               (0x1 << BIT_AIO_9_ADC_DATA_L_3 )
#define BIT_AIO_9_ADC_DATA_L_4                4                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_4               (0x1 << BIT_AIO_9_ADC_DATA_L_4 )
#define BIT_AIO_9_ADC_DATA_L_5                5                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_5               (0x1 << BIT_AIO_9_ADC_DATA_L_5 )
#define BIT_AIO_9_ADC_DATA_L_6                6                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_6               (0x1 << BIT_AIO_9_ADC_DATA_L_6 )
#define BIT_AIO_9_ADC_DATA_L_7                7                                 // Output DATA from Successive Approx, IO_CELL 9, Lower 8 bits
#define MASK_AIO_9_ADC_DATA_L_7               (0x1 << BIT_AIO_9_ADC_DATA_L_7 )
#define MASK_CELL_9_ADC_DATA_L                (0xFF << BIT_AIO_9_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 337 (0x151) AIO_9_ADC_DATA_U_1
#define AIO_9_ADC_DATA_U_1                0x151

// Register 337 Bit Definitions
#define BIT_AIO_9_ADC_DATA_U_0                0                                 // Output DATA from Successive Approx, IO_CELL 9, Upper 2 bits
#define MASK_AIO_9_ADC_DATA_U_0               (0x1 << BIT_AIO_9_ADC_DATA_U_0 )
#define BIT_AIO_9_ADC_DATA_U_1                1                                 // Output DATA from Successive Approx, IO_CELL 9, Upper 2 bits
#define MASK_AIO_9_ADC_DATA_U_1               (0x1 << BIT_AIO_9_ADC_DATA_U_1 )
#define MASK_CELL_9_ADC_DATA_U                (0x3 << BIT_AIO_9_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 338 (0x152) AIO_10_ADC_DATA_L_1
#define AIO_10_ADC_DATA_L_1               0x152

// Register 338 Bit Definitions
#define BIT_AIO_10_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_0              (0x1 << BIT_AIO_10_ADC_DATA_L_0 )
#define BIT_AIO_10_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_1              (0x1 << BIT_AIO_10_ADC_DATA_L_1 )
#define BIT_AIO_10_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_2              (0x1 << BIT_AIO_10_ADC_DATA_L_2 )
#define BIT_AIO_10_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_3              (0x1 << BIT_AIO_10_ADC_DATA_L_3 )
#define BIT_AIO_10_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_4              (0x1 << BIT_AIO_10_ADC_DATA_L_4 )
#define BIT_AIO_10_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_5              (0x1 << BIT_AIO_10_ADC_DATA_L_5 )
#define BIT_AIO_10_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_6              (0x1 << BIT_AIO_10_ADC_DATA_L_6 )
#define BIT_AIO_10_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 10, Lower 8 bits
#define MASK_AIO_10_ADC_DATA_L_7              (0x1 << BIT_AIO_10_ADC_DATA_L_7 )
#define MASK_CELL_10_ADC_DATA_L               (0xFF << BIT_AIO_10_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 339 (0x153) AIO_10_ADC_DATA_U_1
#define AIO_10_ADC_DATA_U_1               0x153

// Register 339 Bit Definitions
#define BIT_AIO_10_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 10, Upper 2 bits
#define MASK_AIO_10_ADC_DATA_U_0              (0x1 << BIT_AIO_10_ADC_DATA_U_0 )
#define BIT_AIO_10_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 10, Upper 2 bits
#define MASK_AIO_10_ADC_DATA_U_1              (0x1 << BIT_AIO_10_ADC_DATA_U_1 )
#define MASK_CELL_10_ADC_DATA_U               (0x3 << BIT_AIO_10_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 340 (0x154) AIO_11_ADC_DATA_L_1
#define AIO_11_ADC_DATA_L_1               0x154

// Register 340 Bit Definitions
#define BIT_AIO_11_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_0              (0x1 << BIT_AIO_11_ADC_DATA_L_0 )
#define BIT_AIO_11_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_1              (0x1 << BIT_AIO_11_ADC_DATA_L_1 )
#define BIT_AIO_11_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_2              (0x1 << BIT_AIO_11_ADC_DATA_L_2 )
#define BIT_AIO_11_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_3              (0x1 << BIT_AIO_11_ADC_DATA_L_3 )
#define BIT_AIO_11_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_4              (0x1 << BIT_AIO_11_ADC_DATA_L_4 )
#define BIT_AIO_11_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_5              (0x1 << BIT_AIO_11_ADC_DATA_L_5 )
#define BIT_AIO_11_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_6              (0x1 << BIT_AIO_11_ADC_DATA_L_6 )
#define BIT_AIO_11_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 11, Lower 8 bits
#define MASK_AIO_11_ADC_DATA_L_7              (0x1 << BIT_AIO_11_ADC_DATA_L_7 )
#define MASK_CELL_11_ADC_DATA_L               (0xFF << BIT_AIO_11_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 341 (0x155) AIO_11_ADC_DATA_U_1
#define AIO_11_ADC_DATA_U_1               0x155

// Register 341 Bit Definitions
#define BIT_AIO_11_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 11, Upper 2 bits
#define MASK_AIO_11_ADC_DATA_U_0              (0x1 << BIT_AIO_11_ADC_DATA_U_0 )
#define BIT_AIO_11_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 11, Upper 2 bits
#define MASK_AIO_11_ADC_DATA_U_1              (0x1 << BIT_AIO_11_ADC_DATA_U_1 )
#define MASK_CELL_11_ADC_DATA_U               (0x3 << BIT_AIO_11_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 342 (0x156) AIO_12_ADC_DATA_L_1
#define AIO_12_ADC_DATA_L_1               0x156

// Register 342 Bit Definitions
#define BIT_AIO_12_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_0              (0x1 << BIT_AIO_12_ADC_DATA_L_0 )
#define BIT_AIO_12_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_1              (0x1 << BIT_AIO_12_ADC_DATA_L_1 )
#define BIT_AIO_12_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_2              (0x1 << BIT_AIO_12_ADC_DATA_L_2 )
#define BIT_AIO_12_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_3              (0x1 << BIT_AIO_12_ADC_DATA_L_3 )
#define BIT_AIO_12_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_4              (0x1 << BIT_AIO_12_ADC_DATA_L_4 )
#define BIT_AIO_12_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_5              (0x1 << BIT_AIO_12_ADC_DATA_L_5 )
#define BIT_AIO_12_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_6              (0x1 << BIT_AIO_12_ADC_DATA_L_6 )
#define BIT_AIO_12_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 12, Lower 8 bits
#define MASK_AIO_12_ADC_DATA_L_7              (0x1 << BIT_AIO_12_ADC_DATA_L_7 )
#define MASK_CELL_12_ADC_DATA_L               (0xFF << BIT_AIO_12_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 343 (0x157) AIO_12_ADC_DATA_U_1
#define AIO_12_ADC_DATA_U_1               0x157

// Register 343 Bit Definitions
#define BIT_AIO_12_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 12, Upper 2 bits
#define MASK_AIO_12_ADC_DATA_U_0              (0x1 << BIT_AIO_12_ADC_DATA_U_0 )
#define BIT_AIO_12_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 12, Upper 2 bits
#define MASK_AIO_12_ADC_DATA_U_1              (0x1 << BIT_AIO_12_ADC_DATA_U_1 )
#define MASK_CELL_12_ADC_DATA_U               (0x3 << BIT_AIO_12_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 344 (0x158) AIO_13_ADC_DATA_L_1
#define AIO_13_ADC_DATA_L_1               0x158

// Register 344 Bit Definitions
#define BIT_AIO_13_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_0              (0x1 << BIT_AIO_13_ADC_DATA_L_0 )
#define BIT_AIO_13_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_1              (0x1 << BIT_AIO_13_ADC_DATA_L_1 )
#define BIT_AIO_13_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_2              (0x1 << BIT_AIO_13_ADC_DATA_L_2 )
#define BIT_AIO_13_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_3              (0x1 << BIT_AIO_13_ADC_DATA_L_3 )
#define BIT_AIO_13_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_4              (0x1 << BIT_AIO_13_ADC_DATA_L_4 )
#define BIT_AIO_13_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_5              (0x1 << BIT_AIO_13_ADC_DATA_L_5 )
#define BIT_AIO_13_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_6              (0x1 << BIT_AIO_13_ADC_DATA_L_6 )
#define BIT_AIO_13_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 13, Lower 8 bits
#define MASK_AIO_13_ADC_DATA_L_7              (0x1 << BIT_AIO_13_ADC_DATA_L_7 )
#define MASK_CELL_13_ADC_DATA_L               (0xFF << BIT_AIO_13_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 345 (0x159) AIO_13_ADC_DATA_U_1
#define AIO_13_ADC_DATA_U_1               0x159

// Register 345 Bit Definitions
#define BIT_AIO_13_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 13, Upper 2 bits
#define MASK_AIO_13_ADC_DATA_U_0              (0x1 << BIT_AIO_13_ADC_DATA_U_0 )
#define BIT_AIO_13_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 13, Upper 2 bits
#define MASK_AIO_13_ADC_DATA_U_1              (0x1 << BIT_AIO_13_ADC_DATA_U_1 )
#define MASK_CELL_13_ADC_DATA_U               (0x3 << BIT_AIO_13_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 346 (0x15A) AIO_14_ADC_DATA_L_1
#define AIO_14_ADC_DATA_L_1               0x15A

// Register 346 Bit Definitions
#define BIT_AIO_14_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_0              (0x1 << BIT_AIO_14_ADC_DATA_L_0 )
#define BIT_AIO_14_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_1              (0x1 << BIT_AIO_14_ADC_DATA_L_1 )
#define BIT_AIO_14_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_2              (0x1 << BIT_AIO_14_ADC_DATA_L_2 )
#define BIT_AIO_14_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_3              (0x1 << BIT_AIO_14_ADC_DATA_L_3 )
#define BIT_AIO_14_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_4              (0x1 << BIT_AIO_14_ADC_DATA_L_4 )
#define BIT_AIO_14_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_5              (0x1 << BIT_AIO_14_ADC_DATA_L_5 )
#define BIT_AIO_14_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_6              (0x1 << BIT_AIO_14_ADC_DATA_L_6 )
#define BIT_AIO_14_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 14, Lower 8 bits
#define MASK_AIO_14_ADC_DATA_L_7              (0x1 << BIT_AIO_14_ADC_DATA_L_7 )
#define MASK_CELL_14_ADC_DATA_L               (0xFF << BIT_AIO_14_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 347 (0x15B) AIO_14_ADC_DATA_U_1
#define AIO_14_ADC_DATA_U_1               0x15B

// Register 347 Bit Definitions
#define BIT_AIO_14_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 14, Upper 2 bits
#define MASK_AIO_14_ADC_DATA_U_0              (0x1 << BIT_AIO_14_ADC_DATA_U_0 )
#define BIT_AIO_14_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 14, Upper 2 bits
#define MASK_AIO_14_ADC_DATA_U_1              (0x1 << BIT_AIO_14_ADC_DATA_U_1 )
#define MASK_CELL_14_ADC_DATA_U               (0x3 << BIT_AIO_14_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 348 (0x15C) AIO_15_ADC_DATA_L_1
#define AIO_15_ADC_DATA_L_1               0x15C

// Register 348 Bit Definitions
#define BIT_AIO_15_ADC_DATA_L_0               0                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_0              (0x1 << BIT_AIO_15_ADC_DATA_L_0 )
#define BIT_AIO_15_ADC_DATA_L_1               1                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_1              (0x1 << BIT_AIO_15_ADC_DATA_L_1 )
#define BIT_AIO_15_ADC_DATA_L_2               2                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_2              (0x1 << BIT_AIO_15_ADC_DATA_L_2 )
#define BIT_AIO_15_ADC_DATA_L_3               3                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_3              (0x1 << BIT_AIO_15_ADC_DATA_L_3 )
#define BIT_AIO_15_ADC_DATA_L_4               4                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_4              (0x1 << BIT_AIO_15_ADC_DATA_L_4 )
#define BIT_AIO_15_ADC_DATA_L_5               5                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_5              (0x1 << BIT_AIO_15_ADC_DATA_L_5 )
#define BIT_AIO_15_ADC_DATA_L_6               6                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_6              (0x1 << BIT_AIO_15_ADC_DATA_L_6 )
#define BIT_AIO_15_ADC_DATA_L_7               7                                 // Output DATA from Successive Approx, IO_CELL 15, Lower 8 bits
#define MASK_AIO_15_ADC_DATA_L_7              (0x1 << BIT_AIO_15_ADC_DATA_L_7 )
#define MASK_CELL_15_ADC_DATA_L               (0xFF << BIT_AIO_15_ADC_DATA_L_0 )

//------------------------------------------------------------------------------
// Register 349 (0x15D) AIO_15_ADC_DATA_U_1
#define AIO_15_ADC_DATA_U_1               0x15D

// Register 349 Bit Definitions
#define BIT_AIO_15_ADC_DATA_U_0               0                                 // Output DATA from Successive Approx, IO_CELL 15, Upper 2 bits
#define MASK_AIO_15_ADC_DATA_U_0              (0x1 << BIT_AIO_15_ADC_DATA_U_0 )
#define BIT_AIO_15_ADC_DATA_U_1               1                                 // Output DATA from Successive Approx, IO_CELL 15, Upper 2 bits
#define MASK_AIO_15_ADC_DATA_U_1              (0x1 << BIT_AIO_15_ADC_DATA_U_1 )
#define MASK_CELL_15_ADC_DATA_U               (0x3 << BIT_AIO_15_ADC_DATA_U_0 )

//------------------------------------------------------------------------------
// Register 366 (0x16E) AIO_INTERRUPTS_0_7
#define AIO_INTERRUPTS_0_7                    0x16E

// Register 366 Bit Definitions
#define BIT_AIO_0_INT                         0                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_0_INT                        (0x1 << BIT_AIO_0_INT    )
#define BIT_AIO_1_INT                         1                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_1_INT                        (0x1 << BIT_AIO_1_INT    )
#define BIT_AIO_2_INT                         2                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_2_INT                        (0x1 << BIT_AIO_2_INT    )
#define BIT_AIO_3_INT                         3                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_3_INT                        (0x1 << BIT_AIO_3_INT    )
#define BIT_AIO_4_INT                         4                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_4_INT                        (0x1 << BIT_AIO_4_INT    )
#define BIT_AIO_5_INT                         5                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_5_INT                        (0x1 << BIT_AIO_5_INT    )
#define BIT_AIO_6_INT                         6                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_6_INT                        (0x1 << BIT_AIO_6_INT    )
#define BIT_AIO_7_INT                         7                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_7_INT                        (0x1 << BIT_AIO_7_INT    )

//------------------------------------------------------------------------------
// Register 367 (0x16F) AIO_INTERRUPT_ENABLES_0_7
#define AIO_INTERRUPT_ENABLES_0_7             0x16F

// Register 367 Bit Definitions
#define BIT_AIO_0_IEN                         0                                 // Enable for Cell 0 Interrupt
#define MASK_AIO_0_IEN                        (0x1 << BIT_AIO_0_IEN        )
#define BIT_AIO_1_IEN                         1                                 // Enable for Cell 1 Interrupt
#define MASK_AIO_1_IEN                        (0x1 << BIT_AIO_1_IEN        )
#define BIT_AIO_2_IEN                         2                                 // Enable for Cell 2 Interrupt
#define MASK_AIO_2_IEN                        (0x1 << BIT_AIO_2_IEN        )
#define BIT_AIO_3_IEN                         3                                 // Enable for Cell 3 Interrupt
#define MASK_AIO_3_IEN                        (0x1 << BIT_AIO_3_IEN        )
#define BIT_AIO_4_IEN                         4                                 // Enable for Cell 4 Interrupt
#define MASK_AIO_4_IEN                        (0x1 << BIT_AIO_4_IEN        )
#define BIT_AIO_5_IEN                         5                                 // Enable for Cell 5 Interrupt
#define MASK_AIO_5_IEN                        (0x1 << BIT_AIO_5_IEN        )
#define BIT_AIO_6_IEN                         6                                 // Enable for Cell 6 Interrupt
#define MASK_AIO_6_IEN                        (0x1 << BIT_AIO_6_IEN        )
#define BIT_AIO_7_IEN                         7                                 // Enable for Cell 7 Interrupt
#define MASK_AIO_7_IEN                        (0x1 << BIT_AIO_7_IEN        )

//------------------------------------------------------------------------------
// Register 368 (0x170) AIO_INTERRUPTS_8_15
#define AIO_INTERRUPTS_8_15                   0x170

// Register 368 Bit Definitions
#define BIT_AIO_8_INT                         0                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_8_INT                        (0x1 << BIT_AIO_8_INT    )
#define BIT_AIO_9_INT                         1                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_9_INT                        (0x1 << BIT_AIO_9_INT    )
#define BIT_AIO_10_INT                        2                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_10_INT                       (0x1 << BIT_AIO_10_INT    )
#define BIT_AIO_11_INT                        3                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_11_INT                       (0x1 << BIT_AIO_11_INT    )
#define BIT_AIO_12_INT                        4                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_12_INT                       (0x1 << BIT_AIO_12_INT    )
#define BIT_AIO_13_INT                        5                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_13_INT                       (0x1 << BIT_AIO_13_INT    )
#define BIT_AIO_14_INT                        6                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_14_INT                       (0x1 << BIT_AIO_14_INT    )
#define BIT_AIO_15_INT                        7                                 // ADC Mode, Int indicates Sample Done. Event Mode, interrupt indicates Event detected
#define MASK_AIO_15_INT                       (0x1 << BIT_AIO_15_INT    )

//------------------------------------------------------------------------------
// Register 369 (0x171) AIO_INTERRUPT_ENABLES_8_15
#define AIO_INTERRUPT_ENABLES_8_15            0x171

// Register 369 Bit Definitions
#define BIT_AIO_8_IEN                         0                                 // Enable for Cell  8  Interrupt
#define MASK_AIO_8_IEN                        (0x1 << BIT_AIO_8_IEN        )
#define BIT_AIO_9_IEN                         1                                 // Enable for Cell  9  Interrupt
#define MASK_AIO_9_IEN                        (0x1 << BIT_AIO_9_IEN        )
#define BIT_AIO_10_IEN                        2                                 // Enable for Cell  10 Interrupt
#define MASK_AIO_10_IEN                       (0x1 << BIT_AIO_10_IEN        )
#define BIT_AIO_11_IEN                        3                                 // Enable for Cell  11 Interrupt
#define MASK_AIO_11_IEN                       (0x1 << BIT_AIO_11_IEN        )
#define BIT_AIO_12_IEN                        4                                 // Enable for Cell  12 Interrupt
#define MASK_AIO_12_IEN                       (0x1 << BIT_AIO_12_IEN        )
#define BIT_AIO_13_IEN                        5                                 // Enable for Cell  13 Interrupt
#define MASK_AIO_13_IEN                       (0x1 << BIT_AIO_13_IEN        )
#define BIT_AIO_14_IEN                        6                                 // Enable for Cell  14 Interrupt
#define MASK_AIO_14_IEN                       (0x1 << BIT_AIO_14_IEN        )
#define BIT_AIO_15_IEN                        7                                 // Enable for Cell  15 Interrupt
#define MASK_AIO_15_IEN                       (0x1 << BIT_AIO_15_IEN        )

//------------------------------------------------------------------------------
// Register 374 (0x176) AIO_SH_COUNTER_L_
#define AIO_SH_COUNTER_L                      0x176

// Register 374 Bit Definitions
#define BIT_SH_SETTLING_TIME_L_0              0                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_0             (0x1 << BIT_SH_SETTLING_TIME_L_0)
#define BIT_SH_SETTLING_TIME_L_1              1                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_1             (0x1 << BIT_SH_SETTLING_TIME_L_1)
#define BIT_SH_SETTLING_TIME_L_2              2                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_2             (0x1 << BIT_SH_SETTLING_TIME_L_2)
#define BIT_SH_SETTLING_TIME_L_3              3                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_3             (0x1 << BIT_SH_SETTLING_TIME_L_3)
#define BIT_SH_SETTLING_TIME_L_4              4                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_4             (0x1 << BIT_SH_SETTLING_TIME_L_4)
#define BIT_SH_SETTLING_TIME_L_5              5                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_5             (0x1 << BIT_SH_SETTLING_TIME_L_5)
#define BIT_SH_SETTLING_TIME_L_6              6                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_6             (0x1 << BIT_SH_SETTLING_TIME_L_6)
#define BIT_SH_SETTLING_TIME_L_7              7                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_L_7             (0x1 << BIT_SH_SETTLING_TIME_L_7)
#define MASK_SH_SETTLING_TIME_L               (0xFF << BIT_SH_SETTLING_TIME_L_0)

//------------------------------------------------------------------------------
// Register 375 (0x177) AIO_SH_COUNTER_U_1
#define AIO_SH_COUNTER_U_1                    0x177

// Register 375 Bit Definitions
#define BIT_SH_SETTLING_TIME_U_0              0                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_U_0             (0x1 << BIT_SH_SETTLING_TIME_U_0)
#define BIT_SH_SETTLING_TIME_U_1              1                                 // Modifies the counter value used to wait for Sample & Hold settling time
#define MASK_SH_SETTLING_TIME_U_1             (0x1 << BIT_SH_SETTLING_TIME_U_1)
#define MASK_SH_SETTLING_TIME_U               (0x3 << BIT_SH_SETTLING_TIME_U_0)

//------------------------------------------------------------------------------
// Register 378 (0x17A) AIO_CLK_DIV_1
#define AIO_CLK_DIV_1                     0x17A

// Register 378 Bit Definitions
#define BIT_CLK_DIV_0                         0                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_0                        (0x1 << BIT_CLK_DIV_0)
#define BIT_CLK_DIV_1                         1                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_1                        (0x1 << BIT_CLK_DIV_1)
#define BIT_CLK_DIV_2                         2                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_2                        (0x1 << BIT_CLK_DIV_2)
#define BIT_CLK_DIV_3                         3                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_3                        (0x1 << BIT_CLK_DIV_3)
#define BIT_CLK_DIV_4                         4                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_4                        (0x1 << BIT_CLK_DIV_4)
#define BIT_CLK_DIV_5                         5                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_5                        (0x1 << BIT_CLK_DIV_5)
#define BIT_CLK_DIV_6                         6                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_6                        (0x1 << BIT_CLK_DIV_6)
#define BIT_CLK_DIV_7                         7                                 // Clock division ratio. Divider = Value+1. So, set 0 for div of 1, set 1 for div of 2, set 2 for div of 3, etc.
#define MASK_CLK_DIV_7                        (0x1 << BIT_CLK_DIV_7)
#define MASK_CLK_DIV                          (0xFF << BIT_CLK_DIV_0)

#endif // __FT51_IOCELL_REGISTERS_H__
